function plotMesh(file)
%function plotMesh(file)
%Written by Scott T. Marshall 5/18/2010
%
%plotMesh.m is a function that plots poly3d fault meshes as a solid gray triangulated surface.
%This function requires that the user supply the file name (with no extension)
%The function then assumes that file.tri and file.xyz are present.
%Both of the required files are generated by gocad2matlab.pl, getSlip.pl or
%getStress.pl.
%
%This function has a parameter, 'plotColor', that controls whether a gray surface or
%a color depth-shaded surface is plotted.
%
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%start the matlab stopwatch to time the script
tic;

%should I plot a gray surface or a colored depth shaded surface?
%plotColor=1 gives a depth-colored surface and plotColor=0 gives a gray surface 
plotColor = 1;
%should I print eps and vrml files? Use 0 for no and 1 for yes
epsPrint = 0;
vrmlPrint = 0;
%What azimuth and elevation angle should I view from? Map view is azi=0 elev=90.
azi = 0;
elev = 90;

%Use the user supplied filename with no extension, to make strings for each file
%Then load each file and save as a matrix
%First load the triangulation
triMesh = strcat(file,'.tri');
triMesh = load(triMesh);
%Now load the XYZ coordinates of each vertex
vrtx = strcat(file,'.xyz');
vrtx = load(vrtx);

%--------------------------------------------------%
%-----     Make The Plot Of The Fault Mesh    -----%
%--------------------------------------------------%
%start a new figure
%figure(1);
%clf;

%plot the mesh as a transparent triangulation
%trimesh(triMesh,vrtx(:,1),vrtx(:,2),vrtx(:,3),'EdgeColor','interp');
%trimesh(triMesh,vrtx(:,1),vrtx(:,2),vrtx(:,3),'EdgeColor', 'Black');

if plotColor == 1
    %plot the mesh as a depth color-shaded solid surface
    trisurf(triMesh,vrtx(:,1),vrtx(:,2),vrtx(:,3),'FaceColor','interp')
    %make a colorbar and save the handle
    h= colorbar;
    %label the top of the colorbar
    set(get(h,'Title'),'String', 'Elevation (m)');
end

if plotColor == 0
    %plot the mesh as a solid gray surface
    trisurf(triMesh,vrtx(:,1),vrtx(:,2),vrtx(:,3),'FaceColor',[0.85 0.85 0.85]);
end

%now modify the plot properties
axis equal;
xlabel('Easting (km)');
ylabel('Northing (km)');
zlabel('Elevation (km)');
%title('');
%set(get(h,'YLabel'),'String', 'Slip (mm/yr)', 'Rotation', 270,'VerticalAlignment','Bottom');
%set(gcf,'Renderer','OpenGL','WindowStyle','docked');
set(gcf,'Renderer','OpenGL');
%this uses orthographic viewing so stuff far away is not smaller. May want to switch it back to 'Perspective' for viewing large meshes.
%note that perspective seems to destroy axes labels
%set(gca,'Projection','Orthographic');
set(gca,'Projection','Perspective');
%tell Matlab to not rescale the object to fill the plot area, otherwise the default setting is really annoying on 3D plots :(
axis(gca,'vis3d');
%turn on the rotation tool
rotate3d on;
%set the 3D view to map view
view(azi,elev);
hold on;

%-----     WRITE THE PLOT TO FILES     -----%
if (vrmlPrint == 1)
    %write a vrml file for making a 3D PDF
    vrml(gcf,strcat(file,'3D'));
end

if (epsPrint == 1)
    %set the renderer back to 'Painters' so that the print command will print vector eps file
    %Open GL results in a rasterized eps file :(
    set(gcf,'Renderer','Painters');
    print('-depsc', strcat(file,'Mesh')); 
end

%print the elapsed time
toc

return;