#!/usr/bin/perl
# ts2facet.pl
# Written by Scott T. Marshall
# 01/27/2013
# 
# This script reads a gocad t-surf file and converts it to facet format.
# The resultant facet files have the same filenames as the fault name ending .facet
# 
# Usage: ts2facet.pl file.ts
# 
# 
#----------------------------------------------------------------------------------------------------------------#

# Pull file name from the command line.
($tsFile) = @ARGV;

# Make sure that the correct number of arguments have been entered on the command line.
if (@ARGV != 1){
	print "Usage: ts2facet.pl file.ts \n";
	exit;
}#end if

#Open the gocad file for reading and report an error if the file to read from doesn't exist or can't open.
open(TS,"$tsFile") or die("Error: Cannot open file $tsFile");

#Make counters to count vertices and triangles
$countV=0;
$countT=0;
$totV=0;
$totT=0;

#----------------------------------------------------------------------------------------------------------------#
#----------  READ THE GOCAD TSURF FILE  -------------------------------------------------------------------------#
#----------------------------------------------------------------------------------------------------------------#
print "Reading $tsFile\n";
print "Writing Facet Files The Following Faults:\n";
print "-------------------------------------------------------------------------------\n";
print "FaultName NumVertices NumElements\n";
print "-------------------------------------------------------------------------------\n";

while(<TS>){
	chomp;
	@data = split(" ",$_);
	
	if($data[0] =~ "name"){
		$data[0] =~ s/name://;
		$name=$data[0];
		#Add .facet to the filename
		$facetFile = "$name.facet";
		#open the file for writing
		open(FACET,">$facetFile") or die("Error: Cannot create file $facetFile");
	}#end if
	
	#Grab the vrtx data
	elsif($data[0] eq "VRTX"){
		#Increment the vrtx counter
		$countV++;
		#Store the relevant data
		#push(@vNum,$data[1]);
		push(@vNum,$countV);
		push(@x,$data[2]);
		push(@y,$data[3]);
		push(@z,$data[4]);
	}#end if
	
	#Grab the TRGL data
	elsif($data[0] eq "TRGL"){
		#Increment the trgl counter
		$countT++;
		#Store the relevant data
		push(@tNum,$countT);
		push(@t1,$data[1]);
		push(@t2,$data[2]);
		push(@t3,$data[3]);
	}#end if
	
	#When you hit an END line, you can print the info
	elsif($data[0] eq "END"){
		print "$name $countV $countT\n";
		#Write the header line
		print FACET "$countV $countT\n";

		#Write the vertices
		for($i=0; $i<@x; $i++){
			print FACET "$vNum[$i] $x[$i] $y[$i] $z[$i]\n";
		}#end for $i
		
		#Write the triangles
		for($j=0; $j<@t1; $j++){
			print FACET "$tNum[$j] $t1[$j] $t2[$j] $t3[$j]\n";
		}#end for $j
		
		close(FACET);
		
		#keep track of the total vertices and elements
		$totV+=$countV;
		$totT+=$countT;
		
		#Reset all arrays and counters for the next fault
		@vNum=(); 
		@x=();
		@y=();
		@z=();
		@tNum=();
		@t1=();
		@t2=();
		@t3=();
		$countV=0;
		$countT=0;
		
	}#end elsif
	
}#end while

close(TS);

#Print a message
print "-------------------------------------------------------------------------------\n";
print "Found $totV Total Vertices and $totT Total Elements\n";
print "Finished!\n";


